##  Microsoft Azure (IaaS)
Infrastructure-as-a-Service (IaaS) is a service model that delivers computer infrastructure on an outsourced basis to support enterprise operations. Typically, IaaS provides hardware, storage, servers, and data center space or network components. The following diagrams show an example of how to model services of Microsoft Azure as an IaaS solution in SAP LeanIX.
In this case, a sample web application called “Azure web application” uses several IT components, which represent the popular services of Azure. Each IT component is connected to its respective Tech Category and the Provider. As an example, we see that “Azure web application” uses the service "Microsoft Azure DevOps Services" for design and development purposes. The first model shows the Tech Category on its lowest hierarchy level, while the second model uses the SAP LeanIX roll-up functionality, which shows the full hierarchy of the Tech Category.
![1896](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27455ec17a441014a427d392b333e51d_LowRes.png) ![1868](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275596197a4410148c71f445bc098106_LowRes.png)
